| Title: | A plugin package to coerce data structure, vectors and manipulating lists in the Rkward GUI. |
|---|---|
| Description: | A plugin package to coerce data structure, vectors and manipulating lists in the Rkward GUI. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.2 |
| Built: | 2026-06-09 06:24:32 UTC |
| Source: | https://github.com/AlfCano/rk.class.lists |